@@ -1,4 +1,4 @@
-#' calibrate_carbon
+#' Calibrate NEON carbon isotope data using validation data sets.
 #'
 #' `r lifecycle::badge("experimental")`
 #' This function drives a workflow that reads in NEON carbon isotope data
@@ -148,6 +148,12 @@ calibrate_carbon         <- function(inname,
     }
   }
 
+  if (method == "Bowling_2003") {
+    lifecycle::deprecate_warn("0.7.1",
+                              "calibrate_carbon(method = 'Bowling_2003')",
+                              "calibrate_carbon(method = 'gainoffset')")
+  }
+
   #-----------------------------------------------------------
   # Extract reference data from input HDF5 file.
   #-----------------------------------------------------------
@@ -194,18 +200,18 @@ calibrate_carbon         <- function(inname,
 
   ciso_subset <- c(ciso$ambient, ciso$reference)
 
-  if (method == "Bowling_2003") {
+  if (method == "gainoffset" | method == "Bowling_2003") {
 
     ciso_subset_cal <-
       lapply(names(ciso_subset),
              function(x) {
-               calibrate_ambient_carbon_Bowling2003(amb_data_list = ciso_subset[[x]],
-                                                    caldf = cal_df,
-                                                    site = site,
-                                                    filter_data = filter_ambient,
-                                                    force_to_end = force_cal_to_end,
-                                                    force_to_beginning = force_cal_to_beginning,
-                                                    r2_thres = r2_thres)
+               calibrate_ambient_carbon_gainoffset(amb_data_list = ciso_subset[[x]],
+                                                   caldf = cal_df,
+                                                   site = site,
+                                                   filter_data = filter_ambient,
+                                                   force_to_end = force_cal_to_end,
+                                                   force_to_beginning = force_cal_to_beginning,
+                                                   r2_thres = r2_thres)
              })
 
   } else if (method == "linreg") {
